@@ -42,6 +42,8 @@ from chex._src.asserts import assert_tree_all_equal_comparator
 from chex._src.asserts import assert_tree_all_equal_shapes
 from chex._src.asserts import assert_tree_all_equal_structs
 from chex._src.asserts import assert_tree_all_finite
+from chex._src.asserts import assert_tree_no_nones
+from chex._src.asserts import assert_tree_shape_prefix
 from chex._src.asserts import assert_type
 from chex._src.asserts import clear_trace_counter
 from chex._src.asserts import if_args_not_none
@@ -57,10 +59,14 @@ from chex._src.pytypes import ArrayDevice
 from chex._src.pytypes import ArrayNumpy
 from chex._src.pytypes import ArraySharded
 from chex._src.pytypes import ArrayTree
+from chex._src.pytypes import CpuDevice
+from chex._src.pytypes import Device
+from chex._src.pytypes import GpuDevice
 from chex._src.pytypes import Numeric
 from chex._src.pytypes import PRNGKey
 from chex._src.pytypes import Scalar
 from chex._src.pytypes import Shape
+from chex._src.pytypes import TpuDevice
 from chex._src.variants import all_variants
 from chex._src.variants import ChexVariantType
 from chex._src.variants import params_product
@@ -68,7 +74,7 @@ from chex._src.variants import TestCase
 from chex._src.variants import variants
 
 
-__version__ = "0.0.4"
+__version__ = "0.0.5"
 
 __all__ = (
     "all_variants",
@@ -105,13 +111,18 @@ __all__ = (
     "assert_tree_all_equal_shapes",
     "assert_tree_all_equal_structs",
     "assert_tree_all_finite",
+    "assert_tree_no_nones",
+    "assert_tree_shape_prefix",
     "assert_type",
     "ChexVariantType",
     "clear_trace_counter",
+    "CpuDevice",
     "dataclass",
+    "Device",
     "fake_jit",
     "fake_pmap",
     "fake_pmap_and_jit",
+    "GpuDevice",
     "if_args_not_none",
     "mappable_dataclass",
     "Numeric",
@@ -121,6 +132,7 @@ __all__ = (
     "set_n_cpu_devices",
     "Shape",
     "TestCase",
+    "TpuDevice",
     "variants",
 )
 
