@@ -37,6 +37,11 @@ Numeric = Union[Array, Scalar]
 PRNGKey = Array
 Shape = Tuple[int, ...]
 
+CpuDevice = jax.lib.xla_extension.CpuDevice
+GpuDevice = jax.lib.xla_extension.GpuDevice
+TpuDevice = jax.lib.xla_extension.TpuDevice
+Device = Union[CpuDevice, GpuDevice, TpuDevice]
+
 # As of 06/2020 pytype doesn't support recursive types (see b/109648354)
 # pytype: disable=not-supported-yet
 ArrayTree = Union[Array, Iterable['ArrayTree'], Mapping[Any, 'ArrayTree']]
